.. _contributing:

Contributing
============

We really want your contributions!  As an official
`yt-project <http://yt-project.org/>`__ extension, everything in the
`yt Contributor Guide <https://github.com/yt-project/yt#contributing>`__
applies here.

This package uses the same development practices as `yt
<https://github.com/yt-project/yt>`__ itself, including code style and
testing.  As such, please consult the `yt Developer Guide
<http://yt-project.org/docs/dev/developing/index.html>`__.
